# Frequenz Electricity Trading API Release Notes

## Summary

<!-- Here goes a general summary of what this release is about -->

## Upgrading

<!-- Here goes notes on how to upgrade from previous versions, including deprecations and what they should be replaced with -->

## New Features

- Public Order Book API Extension for Real-Time and Historical Streaming

## Bug Fixes

<!-- Here goes notable bug fixes that are worth a special mention or explanation -->
